__copyright__ = 'Copyright (C) 2018 Hiroki Takayasu'
__version__ = '0.0.1'
__license__ = 'MIT'
__author__ = 'Hiroki Takayasu'
__author_email__ = 'hiroki.kana.github@gmail.com'
__url__ = 'https://github.com/hirokikana/paspas'
